@@ -1,11 +1,17 @@
-# Standard library imports
-import copy
+#
+# (C) Copyright 2013 Enthought, Inc., Austin, TX
+# All right reserved.
+#
+# This file is open source software distributed according to the terms in
+# LICENSE.txt
+#
+from __future__ import absolute_import
 
 # Enthought library imports
 from traits.api import Any
 
 # Local imports
-from data_context import DataContext
+from .data_context import DataContext
 
 
 class NameFilterContext(DataContext):
