@@ -15,7 +15,7 @@ from __future__ import absolute_import
 from contextlib import contextmanager
 
 from traits.api import (Any, Bool, HasTraits, Supports, Trait,
-    Undefined, on_trait_change)
+    Undefined, on_trait_change, OBJECT_IDENTITY_COMPARE)
 
 from .i_context import IListenableContext
 
@@ -28,7 +28,9 @@ class TraitslikeContextWrapper(HasTraits):
     # that mirror the context.
 
     # The context we are wrapping.
-    _context = Supports(IListenableContext, rich_compare=False)
+    _context = Supports(
+        IListenableContext, comparison_mode=OBJECT_IDENTITY_COMPARE
+    )
 
     # Whether the communication between traits and context is currently active
     # or not.
@@ -55,12 +57,12 @@ class TraitslikeContextWrapper(HasTraits):
         >>> tcw.add_traits('a', 'b', c=Int)
         """
         if self._context is not None:
-            keys = self._context.keys()
+            keys = list(self._context.keys())
         else:
             keys = []
 
         with self._synch_off():
-            for name, trait in [(x, Any()) for x in args] + kwds.items():
+            for name, trait in [(x, Any()) for x in args] + list(kwds.items()):
                 self.add_trait(name, Trait(trait, in_context=True))
                 # Set the value to that in the context.
                 if name in keys:
